@@ -23,9 +23,9 @@
 
 import json
 import pathlib
-import re
 from typing import Callable
 
+import regex
 import ryml
 
 from fourcipp.utils.typing import Path
@@ -50,12 +50,12 @@ def load_yaml(path_to_yaml_file: Path) -> dict:
     )
 
     # Convert `inf` to a string to avoid JSON parsing errors, see https://github.com/biojppm/rapidyaml/issues/312
-    json_str = re.sub(r":\s*(-?)inf\b", r': "\1inf"', json_str)
+    json_str = regex.sub(r":\s*(-?)inf\b", r': "\1inf"', json_str)
 
     # Convert floats that are missing digits on either side of the decimal point
     # so .5 to 0.5 and 5. to 5.0
-    json_str = re.sub(r":\s*(-?)\.([0-9]+)", r": \g<1>0.\2", json_str)
-    json_str = re.sub(r":\s*(-?)([0-9]+)\.(\D)", r": \1\2.0\3", json_str)
+    json_str = regex.sub(r":\s*(-?)\.([0-9]+)", r": \g<1>0.\2", json_str)
+    json_str = regex.sub(r":\s*(-?)([0-9]+)\.(\D)", r": \1\2.0\3", json_str)
 
     data = json.loads(json_str)
 
@@ -147,7 +147,7 @@ def dict_to_yaml_string(
 
     if use_fourcipp_yaml_style:
         # add spaces after commas in vectors
-        yaml_string = re.sub(r"(?<=\d),(?=\d)|(?<=\]),(?=\[)", ", ", yaml_string)
+        yaml_string = regex.sub(r"(?<=\d),(?=\d)|(?<=\]),(?=\[)", ", ", yaml_string)
 
     return yaml_string
 
